"use strict";

var path = require("path");
var packageUtils = require("./util/package");
var ImportUtilities = require("./import_utils");

// XXX TODO Refactor copy & pasted methods to share with the module importer.

function makeImporter(eyeglass, sass, options, fallbackImporter) {
  var root = options.eyeglass.root;

  return function(uri, prev, done) {
    var importUtils = new ImportUtilities(eyeglass, sass, options, fallbackImporter, this);

    var isRealFile = importUtils.existsSync(prev);
    var pkg;
    var mod;

    function importAppAssets(done) {
      importUtils.importOnce({
        contents: eyeglass.assets.asAssetImport(),
        file: "autoGenerated:assets"
      }, done);
    }

    if (uri === "assets") {
      // if not a real file, exit early
      if (!isRealFile) {
        importAppAssets(done);
        return;
      }

      // attempt to load the package and eyeglass definition
      // call done() and return
      pkg = packageUtils.getPackage(prev);
      var dir = path.dirname(pkg.path);
      if (dir && dir !== root) {
        mod = eyeglass.modules.findByPath(dir);
        if (mod) {
          /* eslint max-depth:0 */
          if (mod.assets) {
            importUtils.importOnce({
              contents: modExports.assets.asAssetImport(mod.name),
              file: "autoGenerated:" + mod.name + "/assets"
            }, done);
          } else {
            done(new Error("No assets specified for plugin " + mod.name));
          }

          return;
        }
      }

      // fallthrough- unhandled. just call done() and return
      importAppAssets(done);
      return;
    }

    var fragments = uri.split("/");
    var moduleName = fragments[0];
    var relativePath = fragments.slice(1).join("/");

    if (relativePath !== "assets") {
      importUtils.fallback(uri, prev, done, function() {
        done(sass.NULL);
      });
      return;
    }

    pkg = isRealFile ? packageUtils.getPackage(prev) : root;
    mod = eyeglass.modules.find(moduleName);

    if (mod) {
      if (mod.assets) {
        importUtils.importOnce({
          contents: mod.assets.asAssetImport(moduleName),
          file: "autoGenerated:" + moduleName + "/assets"
        }, done);
      } else {
        done(new Error("No assets specified for eyeglass plugin " + moduleName));
      }
    } else {
      done(new Error("No eyeglass plugin named: " + moduleName));
    }
  };
}

module.exports = makeImporter;
